package eu.jonahbauer.wizard.client.cli.commands;

import eu.jonahbauer.wizard.client.cli.Client;
import eu.jonahbauer.wizard.client.cli.state.Game;
import eu.jonahbauer.wizard.client.cli.util.Pair;
import eu.jonahbauer.wizard.common.model.Card;

import java.util.Map;
import java.util.UUID;

import static picocli.CommandLine.Command;

@Command(name = "show")
public class ShowCommand {
    private final Client client;
    private final Game game;

    public ShowCommand(Client client, Game game) {
        this.client = client;
        this.game = game;
    }

    @Command(name = "players")
    public void players() {
        StringBuilder builder = new StringBuilder();
        for (Map.Entry<UUID, String> player : game.getPlayers().entrySet()) {
            builder.append(player.getValue()).append('\t').append(player.getKey()).append('\n');
        }
        client.println(builder.toString());
    }

    @Command(name = "stack")
    public void stack() {
        StringBuilder builder = new StringBuilder();
        for (Pair<UUID, Card> entry : game.getStack()) {
            builder.append(entry.getValue()).append('\t').append(game.nameOf(entry.getKey())).append('\n');
        }
        client.println(builder.toString());
    }

    @Command(name = "hand")
    public void hand() {
        client.println(game.getHands().get(game.getSelf()));
    }

    @Command(name = "predictions")
    public void predictions() {
        StringBuilder builder = new StringBuilder();
        game.getPredictions().forEach((player, prediction) -> builder.append(game.nameOf(player)).append('\t').append(prediction).append('\n'));
        client.println(builder.toString());
    }

    @Command(name = "trump")
    public void trump() {
        client.printfln("%s (%s)", game.getTrumpSuit(), game.getTrumpCard());
    }
}
