package eu.jonahbauer.wizard.client.libgdx.actors.game;

import com.badlogic.gdx.graphics.g2d.TextureAtlas;
import com.badlogic.gdx.scenes.scene2d.Actor;
import com.badlogic.gdx.scenes.scene2d.InputEvent;
import com.badlogic.gdx.scenes.scene2d.InputListener;
import com.badlogic.gdx.scenes.scene2d.ui.HorizontalGroup;
import eu.jonahbauer.wizard.common.model.Card;

import java.util.List;

public class CardsGroup extends HorizontalGroup {
    private TextureAtlas atlas;
    private List<CardActor> actors;
    private int hash;
    private CardActor target;

    public CardsGroup(List<Card> cards, TextureAtlas atlas) {
        this.atlas = atlas;
        update(cards);

        this.addListener(new InputListener() {
            @Override
            public void enter(InputEvent event, float x, float y, int pointer, Actor fromActor) {
                if (event.getTarget() instanceof CardActor card) {
                    CardsGroup.this.target = card;
                }
            }

            @Override
            public void exit(InputEvent event, float x, float y, int pointer, Actor toActor) {
                if (event.getTarget() == CardsGroup.this.target) {
                    CardsGroup.this.target = null;
                }
            }
        });
    }

    @Override
    public float getMinWidth() {
        return 0;
    }

    @Override
    public void act(float delta) {
        super.act(delta);

        float speed = 10;
        float offset = 100;

        for (Actor child : getChildren()) {
            if (child instanceof CardActor card) {
                if (card == target) {
                    card.offset += speed * delta;
                } else {
                    card.offset -= speed * delta;
                }
                card.offset = Math.max(0, Math.min(1, card.offset));
                card.setHeight(100 + offset * card.offset);
            }
        }
    }

    @Override
    public void layout() {
        super.layout();
        var space = getWidth();
        for (Actor child : getChildren()) {
            space -= child.getWidth();
            if (child instanceof CardActor card) {
                card.baseY = card.getY();
            }
        }
        space(getChildren().size > 1 ? space / (getChildren().size - 1) : 0);
        super.layout();
    }

    public void update(List<Card> cards) {
        var hash = cards.hashCode();
        if (this.hash != hash) {
            this.hash = hash;
            this.actors = cards.stream().map(card -> new CardActor(card, atlas)).toList();
            this.clearChildren();
            this.actors.forEach(this::addActor);
            this.layout();
        }
    }
}
