package eu.jonahbauer.wizard.client.libgdx.actors.game;

import com.badlogic.gdx.scenes.scene2d.ui.Cell;
import com.badlogic.gdx.scenes.scene2d.ui.Label;
import com.badlogic.gdx.scenes.scene2d.ui.Skin;
import com.badlogic.gdx.scenes.scene2d.ui.Table;
import eu.jonahbauer.wizard.common.model.Card;
import lombok.AccessLevel;
import lombok.Setter;

import java.util.List;
import java.util.Map;
import java.util.UUID;

public class InfoTable extends Table {

    private final UUID[] players;
    private final Skin skin;

    @Setter(AccessLevel.MODULE)
    private int round = -1;
    private int playercount; //optional
    private Cell cells[][];
    private static final int TABLELENGTH = 4;
    private static final int PLAYERNAMES = 0;
    private static final int PREDICTIONS = 1;
    private static final int TRICKS = 2;
    private static final int SCORES = 3;
    private final String headers[] = {"Spieler", "Vorhersage", "Stiche", "Punktzahl"};

    public InfoTable(Skin skin, UUID[] players) {
        super(skin);
        this.skin = skin;
        this.players = players;
        playercount = players.length;
        cells = new Cell[TABLELENGTH][playercount];
        createHeader();
        //this.columnDefaults(1).width(5);
    }

    public void createHeader() {
        for (int i = 0; i < headers.length; i++) {
            Label header = new Label(headers[i], skin);
            //header.setWidth(5);
            //header.setEllipsis(true);
            add(header).padRight(5);
        }
        row();
    }

    public void fill(Map<UUID, String> names, Map<UUID, Integer> predictions, Map<UUID, List<List<Card>>> tricks,
                     Map<Integer, Map<UUID, Integer>> scores) {

        for(int i = 0; i < players.length; i++) {
            //Name
            cells[PLAYERNAMES][i] = add(names.get(players[i]));
            ((Label) cells[PLAYERNAMES][i].getActor()).setWidth(10);
            ((Label) cells[PLAYERNAMES][i].getActor()).setEllipsis(true);

            //Prediction
            cells[PREDICTIONS][i] = add(String.valueOf(predictions.get(players[i])));
            ((Label) cells[PLAYERNAMES][i].getActor()).setEllipsis(true);

            //Tricks
            cells[TRICKS][i] = add(String.valueOf(tricks.get(players[i]).size()));
            ((Label) cells[PLAYERNAMES][i].getActor()).setEllipsis(true);

            //Scores
            //TODO Rundencheck - Rundenupdate
            cells[SCORES][i] = add(String.valueOf(scores.get(round).get(players[i])));
            ((Label) cells[PLAYERNAMES][i].getActor()).setEllipsis(true);

            row();
        }
    }

    public void updatePrediction(Map<UUID, Integer> predictions) {
        for(int i = 0; i < players.length; i++) {
            ((Label) cells[PREDICTIONS][i].getActor()).setText(String.valueOf(predictions.get(players[i])));
        }
    }

    public void updateTricks(Map<UUID, List<List<Card>>> tricks) {
        for(int i = 0; i < players.length; i++) {
            ((Label) cells[TRICKS][i].getActor()).setText(String.valueOf(tricks.get(players[i]).size()));
        }
    }

    public void updateScores(Map<Integer, Map<UUID, Integer>> scores) {
        for(int i = 0; i < players.length; i++) {
            ((Label) cells[SCORES][i].getActor()).setText(String.valueOf(scores.get(round).get(players[i])));
        }
    }

    //TODO - update/removePlayer
}
